==> haskell-success-0.2.6-29-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: success
version: 0.2.6
id: success-0.2.6-GYzvUGu10peG9wef4cEMYy
key: success-0.2.6-GYzvUGu10peG9wef4cEMYy
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/success
synopsis: A version of Either specialised for encoding of success or failure
description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.
category: Data, Failure
abi: 218a261ec82ad7e2518d8b5734042a2d
exposed: True
exposed-modules:
    Success.Impure Success.Pure
import-dirs: /usr/lib/ghc-8.4.3/site-local/success-0.2.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/success-0.2.6
hs-libraries: HSsuccess-0.2.6-GYzvUGu10peG9wef4cEMYy
depends:
    transformers-base-0.4.5.2-7xVlmRHmqPgJ9CKrGJjQpF
    monad-control-1.0.2.3-FWwNNCuNIgjJd2XsTHXvao mtl-2.2.2
    transformers-0.5.5.0 base-4.11.1.0
abi-depends: transformers-base-0.4.5.2-7xVlmRHmqPgJ9CKrGJjQpF=05116e22005b011db3585a0ba0745a2f
             monad-control-1.0.2.3-FWwNNCuNIgjJd2XsTHXvao=af00e93b6b2a16db6aef7d1ccc0d036c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-success/html/success.haddock
haddock-html: /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-success-0.2.6-32-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: success
version: 0.2.6
id: success-0.2.6-2babbNf9DT49bbkqTRtQOb
key: success-0.2.6-2babbNf9DT49bbkqTRtQOb
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/success
synopsis: A version of Either specialised for encoding of success or failure
description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.
category: Data, Failure
abi: 08ec29f1cb2f76abe1924bdc2dc878f9
exposed: True
exposed-modules:
    Success.Impure Success.Pure
import-dirs: /usr/lib/ghc-8.6.1/site-local/success-0.2.6
library-dirs: /usr/lib/ghc-8.6.1/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/success-0.2.6
hs-libraries: HSsuccess-0.2.6-2babbNf9DT49bbkqTRtQOb
depends:
    base-4.12.0.0 monad-control-1.0.2.3-GTHTd3ANl4bLcDnP0abGmh
    mtl-2.2.2 transformers-0.5.5.0
    transformers-base-0.4.5.2-IJREwika6Q09fUjnypf1lr
haddock-interfaces: /usr/share/doc/haskell-success/html/success.haddock
haddock-html: /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
